#!/bin/bash
#
# author           : George Vlahavas (vlahavas~AT~gmail~DOT~com, gapan@zenwalk forums)
# project web page : http://xml.apache.org/xerces-c/
# source           : http://www.apache.org/dist/xml/xerces-c/xerces-c-current.tar.gz

# Package name
NAME="xerces"
# Package version
VERSION="2.7.0"
# Tarball name
TARBALL="xerces-c-current.tar.gz"
# Source code URL
SOURCE="http://www.apache.org/dist/xml/xerces-c/xerces-c-current.tar.gz"
# Files that should be placed in the documentation dir
DOCS="doc/html KEYS LICENSE NOTICE Readme.html STATUS credits.txt"

CWD=`pwd`
PKG="$CWD/$NAME-install"

# where the tarball is extracted
EXTRACTDIR="$CWD/xerces-c-src_2_7_0"

ARCH="i486"
CPU="i686"
BUILD="48.1"

rm -rf $PKG
mkdir -p $PKG

# Create package install directory
mkdir $PKG/install

# Create the slack-desc file
cat > $PKG/install/slack-desc << END
$NAME: Xerces-C++ is a validating XML parser written in a portable subset of C++
$NAME:
$NAME: Xerces-C++ makes it easy to give your application the ability to
$NAME: read and write XML data. A shared library is provided for parsing,
$NAME: generating, manipulating, and validating XML documents. Xerces-C++
$NAME: is faithful to the XML 1.0 recommendation and many associated 
$NAME: standards. The parser provides high performance, modularity, and
$NAME: scalability. Source code, samples and API documentation are
$NAME: provided with the parser. For portability, care has been taken to
$NAME: make minimal use of templates, no RTTI, and minimal use of #ifdefs.
$NAME:
END


# Check to see if source is present. If it's not, download it
rm -rf $NAME-$VERSION
if [ -f $TARBALL ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $SOURCE
fi

# Unpack source
tar xvzf $TARBALL

# Configure and make
cd $EXTRACTDIR
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export XERCESCROOT="$EXTRACTDIR"
cd $XERCESCROOT/src/xercesc
autoconf
# Patch the runConfigure file to use the right flags
sed -i -e 's/-O //' runConfigure
./runConfigure -plinux -P/usr
gmake

# We're going to remove some symlinks because they are going to cause
# trouble during packaging. We'll add them later manually in doinst.sh
cd $EXTRACTDIR/lib
rm -rf libxerces-c.so libxerces-c.so.27 libxerces-depdom.so libxerces-depdom.so.27

# Install on temporary directory
cd $EXTRACTDIR
mkdir -p $PKG/usr/include
mkdir -p $PKG/usr/lib
cp -a include/* $PKG/usr/include
cp -a lib/* $PKG/usr/lib

# Strip binaries
cd $PKG
find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# Create html docs
cd $EXTRACTDIR
chmod +x createDocs.sh
./createDocs.sh

# Copy Docs
mkdir -p $PKG/usr/doc/$NAME-$VERSION
cd $EXTRACTDIR
cp -a $DOCS $PKG/usr/doc/$NAME-$VERSION

# Add the build-file in the package
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

# Create the doinst.sh file as it should be
cat > $PKG/install/doinst.sh << END
( cd usr/lib ; rm -rf libxerces-c.so )
( cd usr/lib ; ln -sf libxerces-c.so.27 libxerces-c.so )
( cd usr/lib ; rm -rf libxerces-c.so.27 )
( cd usr/lib ; ln -sf libxerces-c.so.27.0 libxerces-c.so.27 )
( cd usr/lib ; rm -rf libxerces-depdom.so )
( cd usr/lib ; ln -sf libxerces-depdom.so.27 libxerces-depdom.so )
( cd usr/lib ; rm -rf libxerces-depdom.so.27 )
( cd usr/lib ; ln -sf libxerces-depdom.so.27.0 libxerces-depdom.so.27 )
END

# Make sure ownerships and permissions are sane
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Make the package
makepkg -l y -c n $CWD/$NAME-$VERSION-$ARCH-$BUILD.tgz

# Calculate md5sum
cd $CWD/
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5

# Remove source-code and temporary install directories
# since they are not needed anymore
rm -rf $EXTRACTDIR
rm -rf $PKG
